# generated by datamodel-codegen:
#   filename:  sftp-composer.spec.json
#   timestamp: 2021-05-26T09:43:37+00:00

from __future__ import annotations

from typing import List, Optional

from pydantic import BaseModel


class DirectoryMapping(BaseModel):
    UserPath: Optional[str] = None
    BucketPath: Optional[str] = None


class SftpComposer(BaseModel):
    HomeDirectoryDetails: Optional[List[DirectoryMapping]] = None
    PublicKeys: Optional[List[str]] = None
    Role: Optional[str] = None
