#!/usr/bin/env python
#  -*- coding: utf-8 -*-
# SPDX-License-Identifier: MPL-2.0
# Copyright 2020-2021 John Mille<john@compose-x.io>

"""Top-level package for AWS SFTP Composer."""

__author__ = """John Preston"""
__email__ = "john@compose-x.io"
__version__ = "0.0.1"
